@@ -58,6 +58,7 @@
 #define CT_COPY     8
 
 /* input data formats (bit mask) */
+#define FT_UNDETERMINED 0
 #define FT_DOS    1
 #define FT_UNIX   2
 #define FT_MIXED  3
@@ -100,7 +101,7 @@ int convert(char *fn, int convType) {
     char buffer1[BUFFER_SIZE], buffer2[BUFFER_SIZE * 2], *outBuffer = (char *)&buffer2;
     int count1 = -1, count2 = -1, n1;
     int crFlag = 0, validDosEolFound = 0;
-    int fileType = 0, fileFlags = 0;
+    int fileType = FT_UNDETERMINED, fileFlags = 0;
     char *tempFn = NULL;
     char *tempFnTemplate = "/dos2unix-XXXXXX";
     char *tmpdir = NULL;
@@ -131,7 +132,7 @@ int convert(char *fn, int convType) {
 
     /* open the input file, if it isn't stdin */
     if (fn != NULL) {
-        if ((in = fopen(fn, "r")) == NULL)
+        if ((in = fopen(fn, "rb")) == NULL)
             BAIL (-1, fn);
         if (stat(fn, &buf) != 0)
             BAIL (-1, fn);
@@ -243,7 +244,8 @@ int convert(char *fn, int convType) {
         (fileType == FT_UNIX && convType == CT_DOS2UNIX) ||
         (fileType == FT_UNIX && convType == CT_MAC2UNIX) ||
         (fileType == FT_MAC && convType == CT_DOS2MAC) ||
-        (fileType == FT_MAC && convType == CT_UNIX2MAC))
+        (fileType == FT_MAC && convType == CT_UNIX2MAC) ||
+        (fileType == FT_UNDETERMINED))
     {
         convType = CT_SKIP;
     }
@@ -256,7 +258,7 @@ int convert(char *fn, int convType) {
 
     /* verbose output: input data type */
     if (verbose) {
-        fprintf (stderr, "File format of '%s': ", fn);
+        fprintf (stderr, "File format of '%s': ", (fn != NULL) ? fn : "stdin");
         if ((fileType & FT_BINARY) != 0)
             fprintf (stderr, "looks binary, ");
         if ((fileFlags & FF_STRAYR) != 0)
@@ -270,6 +272,8 @@ int convert(char *fn, int convType) {
                 fprintf (stderr, "DOS line endings found.");
 	    else if ((fileType & FT_UNIX) != 0)
                 fprintf (stderr, "Unix line endings found.");
+            else
+                fprintf (stderr, "undetermined.");
         }
         fprintf (stderr, "\n");
     }
@@ -296,7 +300,7 @@ int convert(char *fn, int convType) {
 
     /* verbose output: conversion type */
     if (verbose & !testmode) {
-        fprintf (stderr, "Conversion type '%s': ", fn);
+        fprintf (stderr, "Conversion type '%s': ", (fn != NULL) ? fn : "stdin");
         switch (convType) {
             case CT_DOS2UNIX:
                 fprintf (stderr, "DOS -> Unix");
@@ -334,12 +338,12 @@ int convert(char *fn, int convType) {
 
 
     /* open input data in temp file */
-    if ((in = fopen(tempFn, "r")) == NULL)
+    if ((in = fopen(tempFn, "rb")) == NULL)
         BAIL (-2, argv0);
 
     /* open the output file, if it isn't stdout */
     if (fn != NULL) {
-        if ((out = fopen(fn, "w")) == NULL)
+        if ((out = fopen(fn, "wb")) == NULL)
             BAIL (-2, fn);
     }
     else
